==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/SHIFTDAYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.TIME;


/**
 * <p>Classe Java pour SHIFTDAYID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="SHIFTDAYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SHIFTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SHIFTDAYNUMBER"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SHIFTSTARTTIME"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SHIFTDAYID_Type", propOrder = {
    "shiftid",
    "shiftdaynumber",
    "shiftstarttime"
})
public class SHIFTDAYID_Type {

    @XmlElement(name = "SHIFTID", required = true)
    protected SHIFTID_Type shiftid;
    @XmlElement(name = "SHIFTDAYNUMBER")
    protected long shiftdaynumber;
    @XmlElement(name = "SHIFTSTARTTIME", required = true)
    protected TIME shiftstarttime;

    /**
     * Obtient la valeur de la propriété shiftid.
     * 
     * @return
     *     possible object is
     *     {@link SHIFTID_Type }
     *     
     */
    public SHIFTID_Type getSHIFTID() {
        return shiftid;
    }

    /**
     * Définit la valeur de la propriété shiftid.
     * 
     * @param value
     *     allowed object is
     *     {@link SHIFTID_Type }
     *     
     */
    public void setSHIFTID(SHIFTID_Type value) {
        this.shiftid = value;
    }

    /**
     * Obtient la valeur de la propriété shiftdaynumber.
     * 
     */
    public long getSHIFTDAYNUMBER() {
        return shiftdaynumber;
    }

    /**
     * Définit la valeur de la propriété shiftdaynumber.
     * 
     */
    public void setSHIFTDAYNUMBER(long value) {
        this.shiftdaynumber = value;
    }

    /**
     * Obtient la valeur de la propriété shiftstarttime.
     * 
     * @return
     *     possible object is
     *     {@link TIME }
     *     
     */
    public TIME getSHIFTSTARTTIME() {
        return shiftstarttime;
    }

    /**
     * Définit la valeur de la propriété shiftstarttime.
     * 
     * @param value
     *     allowed object is
     *     {@link TIME }
     *     
     */
    public void setSHIFTSTARTTIME(TIME value) {
        this.shiftstarttime = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/SHIFTDAYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.TIME;


/**
 * <p>Java class for SHIFTDAYID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SHIFTDAYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SHIFTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SHIFTDAYNUMBER"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SHIFTSTARTTIME"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SHIFTDAYID_Type", propOrder = {
    "shiftid",
    "shiftdaynumber",
    "shiftstarttime"
})
public class SHIFTDAYID_Type {

    @XmlElement(name = "SHIFTID", required = true)
    protected SHIFTID_Type shiftid;
    @XmlElement(name = "SHIFTDAYNUMBER")
    protected long shiftdaynumber;
    @XmlElement(name = "SHIFTSTARTTIME", required = true)
    protected TIME shiftstarttime;

    /**
     * Gets the value of the shiftid property.
     * 
     * @return
     *     possible object is
     *     {@link SHIFTID_Type }
     *     
     */
    public SHIFTID_Type getSHIFTID() {
        return shiftid;
    }

    /**
     * Sets the value of the shiftid property.
     * 
     * @param value
     *     allowed object is
     *     {@link SHIFTID_Type }
     *     
     */
    public void setSHIFTID(SHIFTID_Type value) {
        this.shiftid = value;
    }

    /**
     * Gets the value of the shiftdaynumber property.
     * 
     */
    public long getSHIFTDAYNUMBER() {
        return shiftdaynumber;
    }

    /**
     * Sets the value of the shiftdaynumber property.
     * 
     */
    public void setSHIFTDAYNUMBER(long value) {
        this.shiftdaynumber = value;
    }

    /**
     * Gets the value of the shiftstarttime property.
     * 
     * @return
     *     possible object is
     *     {@link TIME }
     *     
     */
    public TIME getSHIFTSTARTTIME() {
        return shiftstarttime;
    }

    /**
     * Sets the value of the shiftstarttime property.
     * 
     * @param value
     *     allowed object is
     *     {@link TIME }
     *     
     */
    public void setSHIFTSTARTTIME(TIME value) {
        this.shiftstarttime = value;
    }

}
